<?php
/**
 * Gestion du formulaire de d'édition de carte_territoires.
 */
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

include_spip('inc/actions');
include_spip('inc/editer');

/**
 * Identifier le formulaire en faisant abstraction des paramètres qui ne représentent pas l'objet edité.
 *
 * @param int|string $id_carte    Identifiant du carte_territoires. 'new' pour un nouveau carte_territoires.
 * @param string     $retour      URL de redirection après le traitement
 * @param int        $lier_trad   Identifiant éventuel d'un carte_territoires source d'une traduction
 * @param string     $config_fonc Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array      $row         Valeurs de la ligne SQL de l'objet carte_territoires, si connu
 * @param string     $hidden      Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 *
 * @return string Hash du formulaire
 */
function formulaires_editer_carte_territoires_identifier_dist($id_carte = 'new', $retour = '', $lier_trad = 0, $config_fonc = '', $row = [], $hidden = '') {
	return serialize([(int) $id_carte]);
}

/**
 * Chargement du formulaire d'édition de carte_territoires.
 *
 * Déclarer les champs postés et y intégrer les valeurs par défaut
 *
 * @uses formulaires_editer_objet_charger()
 *
 * @param int|string $id_carte    Identifiant du carte_territoires. 'new' pour un nouveau carte_territoires.
 * @param string     $retour      URL de redirection après le traitement
 * @param int        $lier_trad   Identifiant éventuel d'un carte_territoires source d'une traduction
 * @param string     $config_fonc Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array      $row         Valeurs de la ligne SQL de l'objet carte_territoires, si connu
 * @param string     $hidden      Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 *
 * @return array Environnement du formulaire
 */
function formulaires_editer_carte_territoires_charger_dist($id_carte = 'new', $retour = '', $lier_trad = 0, $config_fonc = '', $row = [], $hidden = '') {
	// Charger l'objet Carte de territoires de façon standard
	$valeurs = formulaires_editer_objet_charger('carte_territoires', $id_carte, '', $lier_trad, $retour, $config_fonc, $row, $hidden);

	// Rajouter la liste des territoires et des exclusions si la carte est de type 'territoire'
	if (
		$valeurs
		and !empty($valeurs['type_carte'])
		and ($valeurs['type_carte'] === 'territoire')
	) {
		// -- liste des territoires inclus
		include_spip('inc/carte_territoires');
		$territoires_inclus = carte_territoires_detourer($valeurs['id_carte'], 'iso_territoire');
		// -- liste des territoires exclus si il y en a
		$parametres = json_decode($valeurs['parametres'], true);
		$territoires_exclus = $parametres['exclusions'] ?? [];
		// -- Construire la liste de tous les territoires avec leur nom
		$territoires = array_merge($territoires_inclus, $territoires_exclus);
		$territoires = sql_allfetsel('iso_territoire, nom_usage', 'spip_territoires', sql_in('iso_territoire', $territoires), '');
		$territoires = array_column($territoires, 'nom_usage', 'iso_territoire');
		asort($territoires);

		$valeurs['_exclusions'] = $territoires;
		$valeurs['_exclusions_defaut'] = $territoires_exclus;
	}

	return $valeurs;
}

/**
 * Vérifications du formulaire d'édition de carte_territoires.
 *
 * Vérifier les champs postés et signaler d'éventuelles erreurs
 *
 * @uses formulaires_editer_objet_verifier()
 *
 * @param int|string $id_carte    Identifiant du carte_territoires. 'new' pour un nouveau carte_territoires.
 * @param string     $retour      URL de redirection après le traitement
 * @param int        $lier_trad   Identifiant éventuel d'un carte_territoires source d'une traduction
 * @param string     $config_fonc Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array      $row         Valeurs de la ligne SQL de l'objet carte_territoires, si connu
 * @param string     $hidden      Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 *
 * @return array Tableau des erreurs
 */
function formulaires_editer_carte_territoires_verifier_dist($id_carte = 'new', $retour = '', $lier_trad = 0, $config_fonc = '', $row = [], $hidden = '') {
	return formulaires_editer_objet_verifier('carte_territoires', $id_carte);
}

/**
 * Traitement du formulaire d'édition de carte_territoires.
 *
 * Traiter les champs postés
 *
 * @uses formulaires_editer_objet_traiter()
 *
 * @param int|string $id_carte    Identifiant du carte_territoires. 'new' pour un nouveau carte_territoires.
 * @param string     $retour      URL de redirection après le traitement
 * @param int        $lier_trad   Identifiant éventuel d'un carte_territoires source d'une traduction
 * @param string     $config_fonc Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array      $row         Valeurs de la ligne SQL de l'objet carte_territoires, si connu
 * @param string     $hidden      Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 *
 * @return array Retours des traitements
 */
function formulaires_editer_carte_territoires_traiter_dist($id_carte = 'new', $retour = '', $lier_trad = 0, $config_fonc = '', $row = [], $hidden = '') {
	return formulaires_editer_objet_traiter('carte_territoires', $id_carte, '', $lier_trad, $retour, $config_fonc, $row, $hidden);
}
